/***************************************************************************
 *   ometer is software for processing biochemical profiling data          *
 *                                                                         *
 *   Copyright (C) 2004 by Pedro Mendes, Virginia Bioinformatics Institute *
 *   mendes@vt.edu                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 ***************************************************************************/

/***************************************************************************
 * datum.cpp header for the datum class - represents all data for          *
 * one single element (metabolite, transcript, etc.)                       *
 ***************************************************************************/
 
#ifndef _DATUM_H_
#define _DATUM_H_

#include <string>

class datum
{
private:
    /**
     *  Name of this datum
     */
    std::string mName;

    /**
     *  Number of replicates for each state
     */
    int *mReplicates;

    /**
     *  Number of states for this datum
     */
    int mStates;
        
    /**
     *  data values for this element
     */
    double **mValue;

    /**
     *  Index for this datum
     */
    unsigned int mIndex;

    /**
     *  Print flag for this datum
     */
    bool mPrint;
    
public:
  datum();
  ~datum();

  int allocateState(int state, int rep);
  void setName(char *n);
  int getReplicates(int state);
  int setStates(int states);
  int getStates();
  void setValue( int state, int i, double val);
  double getValue( int state, int i );
  const char * getName();
  void getStats( int state, double *Avg, double *Std, double *Ssq, double *Res, int *N );
  void setIndex(unsigned int idx);
  unsigned int getIndex();
  void setPrint(bool state);
  bool getPrint();
};

#endif
